aboutsummaryrefslogtreecommitdiffhomepage
path: root/lib/sisu/v0/help.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/sisu/v0/help.rb')
-rw-r--r--lib/sisu/v0/help.rb148
1 files changed, 85 insertions, 63 deletions
diff --git a/lib/sisu/v0/help.rb b/lib/sisu/v0/help.rb
index b2b0a3fe..23cccc04 100644
--- a/lib/sisu/v0/help.rb
+++ b/lib/sisu/v0/help.rb
@@ -1,50 +1,58 @@
=begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
* Author: Ralph Amissah
- * http://www.jus.uio.no/sisu
- * http://www.jus.uio.no/sisu/SiSU/download.html
- * Description: online help
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+ 2007 Ralph Amissah All Rights Reserved.
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
- * License: GPL 2 or later
+ SiSU, a framework for document structuring, publishing and search
- Summary of GPL 2
+ Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+ 2007 Ralph Amissah
- This program is free software; you can redistribute it and/or modify it
- under the terms of the GNU General Public License as published by the Free
- Software Foundation; either version 2 of the License, or (at your option)
- any later version.
+ This program is free software: you can redistribute it and/or modify it
+ under the terms of the GNU General Public License as published by the Free
+ Software Foundation, either version 3 of the License, or (at your option)
+ any later version.
- This program is distributed in the hope that it will be useful, but WITHOUT
- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
- more details.
+ This program is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+ more details.
- You should have received a copy of the GNU General Public License along
- with this program; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ You should have received a copy of the GNU General Public License along with
+ this program. If not, see <http://www.gnu.org/licenses/>.
- If you have Internet connection, the latest version of the GPL should be
- available at these locations:
- http://www.fsf.org/licenses/gpl.html
- http://www.gnu.org/copyleft/gpl.html
- http://www.jus.uio.no/sisu/gpl2.fsf
+ If you have Internet connection, the latest version of the GPL should be
+ available at these locations:
+ <http://www.fsf.org/licenses/gpl.html>
+ <http://www.gnu.org/copyleft/gpl.html>
+ <http://www.jus.uio.no/sisu/gpl.fsf>
- SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+ * Standard SiSU markup syntax,
+ * Standard SiSU meta-markup syntax, and the
+ * Standard SiSU object citation numbering and system
- SiSU uses:
+ * Hompages:
+ <http://www.jus.uio.no/sisu>
+ <http://www.sisudoc.org>
- * Standard SiSU markup syntax,
- * Standard SiSU meta-markup syntax, and the
- * Standard SiSU object citation numbering and system
+ * Download:
+ <http://www.jus.uio.no/sisu/SiSU/download.html>
- © Ralph Amissah 1997, current 2007.
- All Rights Reserved.
+ * Ralph Amissah
+ <ralph@amissah.com>
+ <ralph.amissah@gmail.com>
+
+ ** Description: interactive infomation/help
- * Ralph Amissah: ralph@amissah.com
- ralph.amissah@gmail.com
=end
module SiSU_Help
require "#{SiSU_lib}/sysenv"
@@ -147,7 +155,12 @@ module SiSU_Help
end
def summary
print <<WOK
-if you have not done so, typing sisu on its own or "sisu --help", should give you this sisu help summary and the sisu (interactive help mode) help promt, from which help on each keyword can be obtained.
+ SiSU, Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ License GPL version 3 or Later. This program comes with ABSOLUTELY NO WARRANTY;
+ This is free software, and you are welcome to redistribute it under the conditions of the GPL3 or later.
+ For more license detail type/enter: "sisu --help license"
+
+typing "sisu" on its own or "sisu --help", should give you this sisu help summary and the sisu (interactive help mode) help prompt, from which help on each keyword can be obtained.
alternatively typing #{@cX.orange}sisu --help#{@cX.off} #{@cX.green}[keyword]#{@cX.off} at the command prompt will provide the sisu help page requested and return to the command prompt (if nothing is found it will print this page and return to the command prompt)
@@ -920,7 +933,7 @@ WOK
NB: the verbose flag v included in the generate command string, should
result in a list of output filenames together with their paths.
- The flag U on its own (e.g. sisu -U gpl2.fsf.sst) should provide a list
+ The flag U on its own (e.g. sisu -U gpl3.fsf.sst) should provide a list
of output files that could be generated together with their paths.
(c) #{@cX.green}configuration files#{@cX.off}
@@ -1777,48 +1790,57 @@ WOK
print <<WOK
-* License: GPL 2 or later
+ * License: GPL 3 or later:
- #{@cX.ruby}GPL2 summary#{@cX.off}:
+ SiSU, a framework for document structuring, publishing and search
- This program is free software; you can redistribute it and/or modify it
- under the terms of the GNU General Public License
- #{@cX.blue}http://www.gnu.org/copyleft/gpl.html#{@cX.off}
- as published by the Free Software Foundation;
- #{@cX.blue}http://www.gnu.org/fsf/fsf.html#{@cX.off}
- either version 2 of the License, or (at your option)
- any later version.
+ Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+ 2007 Ralph Amissah
- This program is distributed in the hope that it will be useful, but WITHOUT
- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
- more details.
+ This program is free software: you can redistribute it and/or modify it
+ under the terms of the GNU General Public License as published by the Free
+ Software Foundation, either version 3 of the License, or (at your option)
+ any later version.
- You should have received a copy of the GNU General Public License along
- with this program; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ This program is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+ more details.
- If you have Internet connection, the latest version of the GPL should be
- available at these locations:
- #{@cX.blue}http://www.fsf.org/licenses/gpl.html#{@cX.off}
- #{@cX.blue}http://www.gnu.org/copyleft/gpl.html#{@cX.off}
- #{@cX.blue}http://www.jus.uio.no/sisu/gpl2.fsf#{@cX.off}
+ You should have received a copy of the GNU General Public License along with
+ this program. If not, see <#{@cX.blue}http://www.gnu.org/licenses/#{@cX.off}>.
-* see also the "SiSU Standard" section
+ If you have Internet connection, the latest version of the GPL should be
+ available at these locations:
+ <#{@cX.blue}http://www.fsf.org/licenses/gpl.html#{@cX.off}>
+ <#{@cX.blue}http://www.gnu.org/copyleft/gpl.html#{@cX.off}>
+ <#{@cX.blue}http://www.jus.uio.no/sisu/gpl.fsf#{@cX.off}>
-* Ralph Amissah ralph@amissah.com
- Ralph Amissah ralph.amissah@gmail.com
+ * SiSU uses:
+ * Standard SiSU markup syntax,
+ * Standard SiSU meta-markup syntax, and the
+ * Standard SiSU object citation numbering and system
+
+ * Hompages:
+ <#{@cX.blue}http://www.jus.uio.no/sisu#{@cX.off}>
+ <#{@cX.blue}http://www.sisudoc.org#{@cX.off}>
+
+ * Download:
+ <#{@cX.blue}http://www.jus.uio.no/sisu/SiSU/download.html#{@cX.off}>
+
+ Ralph Amissah
+ <#{@cX.blue}ralph@amissah.com#{@cX.off}>
+ <#{@cX.blue}ralph.amissah@gmail.com#{@cX.off}>
WOK
end
def standards
print <<WOK
-SiSU uses:
-
-* Standard SiSU markup syntax,
-* Standard SiSU meta-markup syntax, and the
-* Standard SiSU object citation numbering and system
+ * SiSU uses:
+ * Standard SiSU markup syntax,
+ * Standard SiSU meta-markup syntax, and the
+ * Standard SiSU object citation numbering and system
© Ralph Amissah 1997, current 2005.
All Rights Reserved.